@@ -2,7 +2,7 @@
 Python wrapper for getting air quality data from GIOS.
 """
 import logging
-from typing import Optional, Union
+from typing import Any, Dict, List, Optional, cast
 
 from aiohttp import ClientSession
 
@@ -26,21 +26,20 @@ _LOGGER = logging.getLogger(__name__)
 class Gios:  # pylint:disable=(too-few-public-methods
     """Main class to perform GIOS API requests"""
 
-    def __init__(self, station_id: str, session: ClientSession):
+    def __init__(self, station_id: str, session: ClientSession) -> None:
         """Initialize."""
-        self.data: dict = {}
         self.station_id = station_id
-        self.latitude: Optional[str] = None
-        self.longitude: Optional[str] = None
+        self.latitude: Optional[float] = None
+        self.longitude: Optional[float] = None
         self.station_name: Optional[str] = None
-        self._station_data: dict = {}
+        self._station_data: List[Dict[str, Any]] = []
 
         self.session = session
 
-    async def update(self):  # pylint:disable=too-many-branches
+    async def async_update(self) -> Dict[str, Any]:  # pylint:disable=too-many-branches
         """Update GIOS data."""
-        data: dict = {}
-        invalid_sensors: list = []
+        data: Dict[str, Dict[str, Any]] = {}
+        invalid_sensors: List[str] = []
 
         if not self.station_name:
             stations = await self._get_stations()
@@ -49,8 +48,8 @@ class Gios:  # pylint:disable=(too-few-public-methods
 
             for station in stations:
                 if station[ATTR_ID] == self.station_id:
-                    self.latitude = station["gegrLat"]
-                    self.longitude = station["gegrLon"]
+                    self.latitude = float(station["gegrLat"])
+                    self.longitude = float(station["gegrLon"])
                     self.station_name = station["stationName"]
             if not self.station_name:
                 raise NoStationError(
@@ -62,10 +61,10 @@ class Gios:  # pylint:disable=(too-few-public-methods
         if not self._station_data:
             raise InvalidSensorsData("Invalid measuring station data from GIOS API")
 
-        for sensor in self._station_data:
-            data[sensor["param"]["paramCode"]] = {
-                ATTR_ID: sensor[ATTR_ID],
-                ATTR_NAME: sensor["param"]["paramName"],
+        for sensor_dict in self._station_data:
+            data[sensor_dict["param"]["paramCode"].lower()] = {
+                ATTR_ID: sensor_dict[ATTR_ID],
+                ATTR_NAME: sensor_dict["param"]["paramName"],
             }
 
         sensors = await self._get_all_sensors(data)
@@ -100,49 +99,49 @@ class Gios:  # pylint:disable=(too-few-public-methods
                     "indexLevelName"
                 ].lower()
 
-            data[ATTR_AQI] = {ATTR_NAME: ATTR_AQI}
-            data[ATTR_AQI][ATTR_VALUE] = indexes["stIndexLevel"][
+            data[ATTR_AQI.lower()] = {ATTR_NAME: ATTR_AQI}
+            data[ATTR_AQI.lower()][ATTR_VALUE] = indexes["stIndexLevel"][
                 "indexLevelName"
             ].lower()
         except (IndexError, KeyError, TypeError) as err:
             raise InvalidSensorsData("Invalid index data from GIOS API") from err
-        self.data = data
+        return data
 
-    async def _get_stations(self) -> dict:
+    async def _get_stations(self) -> List[Dict[str, Any]]:
         """Retreive list of measuring stations."""
-        return await self._async_get(URL_STATIONS)
+        return cast(List[Dict[str, Any]], await self._async_get(URL_STATIONS))
 
-    async def _get_station(self) -> dict:
+    async def _get_station(self) -> List[Dict[str, Any]]:
         """Retreive measuring station data."""
         url = URL_STATION.format(self.station_id)
-        return await self._async_get(url)
+        return cast(List[Dict[str, Any]], await self._async_get(url))
 
-    async def _get_all_sensors(self, sensors: dict) -> dict:
+    async def _get_all_sensors(self, sensors: Dict[str, Any]) -> Dict[str, Any]:
         """Retreive all sensors data."""
-        data: dict = {}
+        data: Dict[str, Any] = {}
         for sensor in sensors:
             sensor_data = await self._get_sensor(sensors[sensor][ATTR_ID])
             data[sensor] = sensor_data
         return data
 
-    async def _get_sensor(self, sensor: int) -> dict:
+    async def _get_sensor(self, sensor: int) -> Dict[str, Any]:
         """Retreive sensor data."""
         url = URL_SENSOR.format(sensor)
         return await self._async_get(url)
 
-    async def _get_indexes(self) -> dict:
+    async def _get_indexes(self) -> Dict[str, Any]:
         """Retreive indexes data."""
         url = URL_INDEXES.format(self.station_id)
         return await self._async_get(url)
 
-    async def _async_get(self, url: str) -> dict:
+    async def _async_get(self, url: str) -> Dict[str, Any]:
         """Retreive data from GIOS API."""
-        data: dict = {}
+        data: Dict[str, Any] = {}
         async with self.session.get(url) as resp:
             _LOGGER.debug("Data retrieved from %s, status: %s", url, resp.status)
             if resp.status != HTTP_OK:
                 _LOGGER.warning("Invalid response from GIOS API: %s", resp.status)
-                raise ApiError(resp.status)
+                raise ApiError(str(resp.status))
             data = await resp.json()
         return data
 
@@ -150,7 +149,7 @@ class Gios:  # pylint:disable=(too-few-public-methods
 class ApiError(Exception):
     """Raised when GIOS API request ended in error."""
 
-    def __init__(self, status: Union[int, str]):
+    def __init__(self, status: str) -> None:
         """Initialize."""
         super().__init__(status)
         self.status = status
@@ -159,7 +158,7 @@ class ApiError(Exception):
 class InvalidSensorsData(Exception):
     """Raised when sensors data is invalid."""
 
-    def __init__(self, status: str):
+    def __init__(self, status: str) -> None:
         """Initialize."""
         super().__init__(status)
         self.status = status
@@ -168,7 +167,7 @@ class InvalidSensorsData(Exception):
 class NoStationError(Exception):
     """Raised when no measuring station error."""
 
-    def __init__(self, status: str):
+    def __init__(self, status: str) -> None:
         """Initialize."""
         super().__init__(status)
         self.status = status
